@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2014 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #include <QApplication>
 #include <QFile>
 #include <QFileInfo>
+#include <QDir>
 
 QString Player::executable(bool * found) {
 	if (found) *found = true;
@@ -33,13 +34,21 @@ QString Player::executable(bool * found) {
 	QFileInfo fi(bin);
 	if (!fi.exists() || !fi.isExecutable() || fi.isDir()) {
 		qDebug("Player::exec: command: '%s' is not a valid executable", bin.toUtf8().constData());
-		bin = "/usr/bin/" + player_bin;
 
+		bin = QDir::homePath() + "/bin/" + player_bin;
 		fi.setFile(bin);
+
 		if (!fi.exists() || !fi.isExecutable() || fi.isDir()) {
 			qDebug("Player::exec: command: '%s' is not a valid executable", bin.toUtf8().constData());
-			bin = player_bin;
-			if (found) *found = false;
+
+			bin = "/usr/bin/" + player_bin;
+			fi.setFile(bin);
+
+			if (!fi.exists() || !fi.isExecutable() || fi.isDir()) {
+				qDebug("Player::exec: command: '%s' is not a valid executable", bin.toUtf8().constData());
+				bin = player_bin;
+				if (found) *found = false;
+			}
 		}
 	}
 #endif
@@ -54,6 +63,7 @@ Players::Players() {
 	list.push_back( Player("Dragon Player", "dragon", false) );
 	list.push_back( Player("Totem", "totem", false) );
 	list.push_back( Player("GNOME-MPlayer", "gnome-mplayer", false) );
+	list.push_back( Player("mpv", "mpv", false, "--title=") );
 
 	curr = 0;
 }
@@ -74,5 +84,5 @@ int Players::findName(QString name) {
 	for (int n = 0; n < list.count(); n++) {
 		if (list[n].name() == name) return n;
 	}
-	return 0;
+	return -1;
 }
