@@ -46,6 +46,7 @@
 
 #ifdef Q_WS_AMIGA // zzd10h
 #include <QProcess>
+#include <QDesktopWidget>
 #endif
 
 RecordingDelegate::RecordingDelegate(QObject *parent)
@@ -232,6 +233,16 @@ RecordingDialog::RecordingDialog(QWidget *parent, QSettings * s) :
     downloadList->setFrameStyle(QFrame::Plain | QFrame::NoFrame);
     downloadList->viewport()->setMouseTracking(true);
     resize(500, 300);
+
+#ifdef Q_WS_AMIGA
+	// zzd10h - center the download recording dialog
+	QDesktopWidget workbench;
+	QRect dimension_workbench = workbench.screenGeometry();
+	int x = dimension_workbench.width()/2 - width()/2;
+	int y = dimension_workbench.height()/2 - height()/2;
+	move(x,y);
+#endif
+
     QAbstractItemModel* downloadModel = downloadList->model();
 
     connect(clearListButton, SIGNAL(clicked()), this, SLOT(clearList()));    
@@ -251,6 +262,17 @@ RecordingDialog::~RecordingDialog()
     }
 }
 
+void RecordingDialog::downloadUrl(const QString & url) {
+    RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
+    rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) recording_quality);
+    connect(rvu, SIGNAL(signatureNotFound(const QString &)), this, SIGNAL(signatureNotFound(const QString &)));
+    connect(rvu, SIGNAL(gotVideoInfo(const QMap<int, QString>&, QString, QString)), this, SLOT(recordVideo(const QMap<int, QString>&, QString, QString)));
+    connect(rvu, SIGNAL(gotVideoInfo(const QMap<int, QString>&, QString, QString)), rvu, SLOT(deleteLater()));
+    rvu->fetchPage(url);
+
+    if (!isVisible()) show();
+}
+
 void RecordingDialog::downloadVideoId(QString videoId, QString title, double)
 {
     RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
@@ -277,7 +299,7 @@ void RecordingDialog::downloadAudioId(QString videoId, QString title, double) {
 }
 
 void RecordingDialog::recordVideo(const QMap<int, QString>& map, QString title, QString id) {
-	qDebug("RecordingDialog::recordVideo");
+	qDebug("RecordingDialog::recordVideo: title: '%s' id: %s", title.toUtf8().constData(), id.toUtf8().constData());
 
 	if (recording_quality == RetrieveYoutubeUrl::MP4_1080p || recording_quality == RetrieveYoutubeUrl::WEBM_1080p) {
 		if (!map.contains(RetrieveYoutubeUrl::MP4_1080p) && !map.contains(RetrieveYoutubeUrl::WEBM_1080p)) {
@@ -286,9 +308,6 @@ void RecordingDialog::recordVideo(const QMap<int, QString>& map, QString title,
 			QString video_url = map.value(RetrieveYoutubeUrl::DASH_VIDEO_1080p, QString());
 			QString audio_url = RetrieveYoutubeUrl::findBestAudio(map);
 			if (!video_url.isEmpty() && !audio_url.isEmpty()) {
-				video_url += "&ratebypass=yes";
-				audio_url += "&ratebypass=yes";
-
 				//qDebug("RecordingDialog::recordVideo: video_url: %s", video_url.toLatin1().constData());
 				//qDebug("RecordingDialog::recordVideo: audio_url: %s", audio_url.toLatin1().constData());
 
@@ -333,7 +352,6 @@ void RecordingDialog::recordAudio(const QMap<int, QString>& map, QString title,
 	qDebug("RecordingDialog::recordAudio");
 
 	QString url = RetrieveYoutubeUrl::findBestAudio(map);
-	url += "&ratebypass=yes";
 
 	if (url.isEmpty()) {
 		QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
