@@ -24,6 +24,7 @@
 #include <QMap>
 
 #define YT_GET_VIDEOINFO
+#define YT_DASH_SUPPORT
 
 class RetrieveYoutubeUrl : public QObject
 {
@@ -54,7 +55,9 @@ public:
 	static QString findPreferredUrl(const QMap<int, QString>& urlMap, Quality q);
 	QString findPreferredUrl();
 
+#ifdef YT_DASH_SUPPORT
 	static QString findBestAudio(const QMap<int, QString>& urlMap);
+#endif
 
 	QString urlTitle() { return url_title; }
 	QString latestPreferredUrl() { return latest_preferred_url; }
@@ -67,6 +70,9 @@ signals:
 	void gotUrls(const QMap<int, QString>&);
 	void gotPreferredUrl(const QString &);
 	void gotEmptyList();
+#ifdef YT_GET_VIDEOINFO
+	void gotVideoInfo(const QMap<int, QString>&, QString, QString);
+#endif
 
 	void connecting(QString host);
 	void errorOcurred(int error_number, QString error_str);
@@ -79,7 +85,7 @@ protected slots:
 #ifdef YT_GET_VIDEOINFO
 	void gotVideoInfoResponse();
 	void parseVideoInfo(QByteArray text);
-	void fetchVideoInfoPage();
+	void fetchVideoInfoPage(QString url = QString::null);
 #endif
 
 protected:
