@@ -36,6 +36,7 @@
 #include <QProcess>
 #include <QClipboard>
 #include <QSettings>
+#include <QInputDialog>
 #include "ytdialog.h"
 #include "yttabbar.h"
 #include "ytdelegate.h"
@@ -230,9 +231,11 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     videoList = new SmoothListWidget(this);
     pixmap_loader = new PixmapLoader;
 
+#ifdef YT_DL
     recording_dialog = new RecordingDialog(0, settings);
     recording_dialog->setRecordingsDirectory("");
     recording_dialog->setRecordingQuality(RetrieveYoutubeUrl::MP4_720p);
+#endif
 
     MyBorder* border = new MyBorder(this);
     border->setBGColor(palette().color(backgroundRole()));
@@ -281,15 +284,26 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     infoButton->setShortcut(QKeySequence("Alt+I"));
     connect(infoButton, SIGNAL(clicked()), this, SLOT(showAboutDialog()));
 
+#ifdef YT_DL
     recordingButton = new QToolButton(this);
     recordingButton->setIcon(QPixmap(":/icons/recordings.png"));
     recordingButton->setToolTip(tr("Show recordings"));
     recordingButton->setShortcut(QKeySequence("Alt+R"));
     connect(recordingButton, SIGNAL(clicked()), recording_dialog, SLOT(show()));
 
+    enterUrlButton = new QToolButton(this);
+    enterUrlButton->setIcon(QPixmap(":/icons/download.png"));
+    enterUrlButton->setToolTip(tr("Enter URL"));
+    enterUrlButton->setShortcut(QKeySequence("Alt+U"));
+    connect(enterUrlButton, SIGNAL(clicked()), this, SLOT(enterUrl()));
+#endif
+
     QHBoxLayout* hbox = new QHBoxLayout;
     hbox->addWidget(searchBox);
+#ifdef YT_DL
     hbox->addWidget(recordingButton);
+    hbox->addWidget(enterUrlButton);
+#endif
     hbox->addWidget(configButton);
     hbox->addWidget(infoButton);
 
@@ -316,17 +330,24 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     connect(videoList, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(videoItemChanged(QListWidgetItem*,QListWidgetItem*)));
     connect(videoList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
 
+#ifdef YT_DL
     connect(recording_dialog, SIGNAL(playFile(QString)), this, SLOT(playVideo(QString)));
     connect(recording_dialog, SIGNAL(signatureNotFound(const QString &)),
             this, SLOT(showErrorSignatureNotFound(const QString &)));
+#endif
 
     /*
     connect(this, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), 
             this, SLOT(playYTUrl(QMap<int,QString>,QString, QString)));
     */
 
+#ifdef YT_DL
     setTabOrder(searchBox, recordingButton);
-    setTabOrder(recordingButton, configButton);
+    setTabOrder(recordingButton, enterUrlButton);
+    setTabOrder(enterUrlButton, configButton);
+#else
+    setTabOrder(searchBox, configButton);
+#endif
     setTabOrder(configButton, infoButton);
     setTabOrder(infoButton, prevButton);
     setTabOrder(prevButton, nextButton);
@@ -374,7 +395,9 @@ YTDialog::~YTDialog()
 	saveConfig();
 
     delete pixmap_loader;
+#ifdef YT_DL
     delete recording_dialog;
+#endif
 }
 
 void YTDialog::setLoadingOverlay(bool enable)
@@ -493,6 +516,13 @@ void YTDialog::addTab(Tabs tab)
     {
         index = tabBar->addTab(tr("Sports"));
     }    
+
+#ifdef Q_WS_AMIGA  // zzd10h  
+    QStringList args = qApp->arguments();
+    if(tab != Relevant && args.count() )
+        tabBar->setTabEnabled(index,false);
+#endif
+
     tabBar->setTabData(index, tab);
 }
 
@@ -639,7 +669,7 @@ void YTDialog::gotAPIReply(const YTReply& formattedReply)
     }
     setLoadingOverlay(false);
 
-    if (error) setMode(YTDialog::Button);
+    if ((error) && (!searchTerm.isEmpty())) setMode(YTDialog::Button);
 }
 
 void YTDialog::gotPixmap(QPixmap pix, int id)
@@ -728,11 +758,13 @@ void YTDialog::videoDblClicked(QListWidgetItem *item)
 }
 
 void YTDialog::showContextMenu(QPoint point)
-{ 
+{
     QMenu menu;
     menu.addAction(tr("&Play video"))->setData("play");
+#ifdef YT_DL
     menu.addAction(tr("&Record video"))->setData("record");
     menu.addAction(tr("R&ecord audio"))->setData("record_audio");
+#endif
     menu.addAction(tr("&Watch on YouTube"))->setData("watch");
     menu.addAction(tr("&Copy link"))->setData("link");
  #ifndef Q_WS_AMIGA // zzd10h
@@ -747,6 +779,7 @@ void YTDialog::showContextMenu(QPoint point)
     {
        videoDblClicked(item);
     }
+#ifdef YT_DL
     else if(action->data().toString() == "record")
     {
        recordItem(item);
@@ -755,6 +788,7 @@ void YTDialog::showContextMenu(QPoint point)
     {
        recordAudioItem(item);
     }
+#endif
     else if(action->data().toString() == "watch")
     {
         SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
@@ -772,6 +806,7 @@ void YTDialog::showContextMenu(QPoint point)
     }
 }
 
+#ifdef YT_DL
 void YTDialog::recordItem(QListWidgetItem *item)
 {
     #ifdef YT_USE_SCRIPT
@@ -792,6 +827,28 @@ void YTDialog::recordAudioItem(QListWidgetItem *item)
     recording_dialog->downloadAudioId(svi->videoid, svi->header, 0);
 }
 
+void YTDialog::downloadUrl(const QString & url) {
+	#ifdef YT_USE_SCRIPT
+	YTSig::setScriptFile(script_file);
+	#endif
+	recording_dialog->downloadUrl(url);
+}
+
+void YTDialog::enterUrl() {
+	qDebug("YTDialog::enterUrl");
+	QString url = QInputDialog::getText(this, tr("Enter a URL"),
+                                        tr("Enter a Youtube URL to record"));
+	if (!url.isEmpty()) {
+		RetrieveYoutubeUrl r(this);
+		QString full_url = r.fullUrl(url);
+		qDebug("RecordingDialog::enterUrl: full_url: %s", full_url.toUtf8().constData());
+		if (!full_url.isEmpty()) {
+			downloadUrl(full_url);
+		}
+	}
+}
+#endif // YT_DL
+
 void YTDialog::playVideo(QString file) 
 {
 #ifdef USE_PLAYERS
@@ -874,12 +931,25 @@ void YTDialog::handleMessage(const QString& message)
         qDebug("YTDialog::handleMessage: search_term: '%s'", search_term.toUtf8().constData());
         setSearchTerm(search_term);
     }
+	#ifdef YT_DL
+    else
+    if (message.startsWith("download "))
+    {
+        QString download_url = message.mid(9);
+        qDebug("YTDialog::handleMessage: download_url: '%s'", download_url.toUtf8().constData());
+        downloadUrl(download_url);
+    }
+	#endif
 }
 #endif
 
 void YTDialog::showErrorDialog(const QString & error) 
 {
+ #ifndef Q_WS_AMIGA  // zzd10h
     QMessageBox::warning(this, tr("Error"), error);
+ #else
+    QMessageBox::warning(this, tr("Error"),"<center>"+error.leftJustified(150, ' ')+"</center>");
+ #endif
 }
 
 void YTDialog::showErrorSignatureNotFound(const QString & title) {
@@ -918,8 +988,10 @@ void YTDialog::showConfigDialog()
     qDebug("YTDialog::showConfigDialog");
 
     ConfigDialog d(this);
+#ifdef YT_DL
     d.setRecordingDirectory(recording_dialog->recordingsDirectory());
     d.setRecordingQuality(recording_dialog->recordingQuality());
+#endif
 #ifdef USE_PLAYERS
     d.setPlayerNames( players.availablePlayers() );
     d.setPlayer( players.currentPlayer().name() );
@@ -933,8 +1005,10 @@ void YTDialog::showConfigDialog()
     d.setRegion( region );
 
     if (d.exec() == QDialog::Accepted) {
+        #ifdef YT_DL
         recording_dialog->setRecordingsDirectory(d.recordingDirectory());
         recording_dialog->setRecordingQuality(d.recordingQuality());
+        #endif
         #ifdef USE_PLAYERS
         int p = players.findName(d.player());
         if (p == -1) p = 0;
@@ -953,11 +1027,15 @@ void YTDialog::showConfigDialog()
 
 void YTDialog::loadConfig() 
 {
+#ifdef YT_DL
     QString recording_directory;
+#endif
     if (set) {
         set->beginGroup("General");
+        #ifdef YT_DL
         recording_directory = set->value("recording_directory", recording_dialog->recordingsDirectory()).toString();
         recording_dialog->setRecordingQuality(set->value("record_quality", recording_dialog->recordingQuality()).toInt());
+        #endif
 #ifdef USE_PLAYERS
         players.setCurrent(set->value("player", players.current()).toInt());
 #endif
@@ -969,11 +1047,21 @@ void YTDialog::loadConfig()
         api->setRegion(set->value("region", local_region).toString());
         api->setPeriod(set->value("period", "today").toString());
         playback_quality = set->value("playback_quality", playback_quality).toInt();
-        RetrieveYoutubeUrl::setUserAgent(set->value("user_agent", "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1").toString());
+        /* RetrieveYoutubeUrl::setUserAgent(set->value("user_agent", "Mozilla/5.0 (X11; Linux x86_64; rv:5.0.1) Gecko/20100101 Firefox/5.0.1").toString()); */
+        RetrieveYoutubeUrl::setUserAgent(set->value("user_agent", "").toString());
         FontPref::base_size = set->value("font_base_size", FontPref::base_size).toInt();
+
+        int config_version = set->value("config_version", 0).toInt();
+        if (config_version < 1) {
+            qDebug("YTDialog::loadConfig: reseting some options");
+            config_version = 1;
+            set->setValue("config_version", config_version);
+            RetrieveYoutubeUrl::setUserAgent("");
+        }
         set->endGroup();
     }
 
+#ifdef YT_DL
     if (!recording_directory.isEmpty()) {
         recording_dialog->setRecordingsDirectory(recording_directory);
     } else {
@@ -1015,14 +1103,17 @@ void YTDialog::loadConfig()
         recording_dialog->setRecordingsDirectory(default_recording_folder);
 #endif
     }
+#endif // YT_DL
 }
 
 void YTDialog::saveConfig() 
 {
     if (set) {
         set->beginGroup("General");
+        #ifdef YT_DL
         set->setValue("recording_directory", recording_dialog->recordingsDirectory());
         set->setValue("record_quality", recording_dialog->recordingQuality());
+        #endif
         #ifdef USE_PLAYERS
         set->setValue("player", players.current());
         #endif
